@@ -140,8 +140,10 @@
 #define fits_read_key_dblcmp   ffgkym
 #define fits_read_key_triple   ffgkyt
 #define fits_get_key_strlen    ffgksl
+#define fits_get_key_com_strlen ffgkcsl
 #define fits_read_key_longstr  ffgkls
 #define fits_read_string_key   ffgsky
+#define fits_read_string_key_com  ffgskyc
 #define fits_free_memory       fffree
 #define fits_read_tdim         ffgtdm
 #define fits_read_tdimll       ffgtdmll
@@ -169,6 +171,7 @@
 #define fits_update_key_longstr    ffukls
 #define fits_update_key_log    ffukyl
 #define fits_update_key_lng    ffukyj
+#define fits_update_key_ulng   ffukyuj
 #define fits_update_key_fixflt ffukyf
 #define fits_update_key_flt    ffukye
 #define fits_update_key_fixdbl ffukyg
@@ -187,6 +190,7 @@
 #define fits_modify_key_longstr    ffmkls
 #define fits_modify_key_log    ffmkyl
 #define fits_modify_key_lng    ffmkyj
+#define fits_modify_key_ulng   ffmkyuj
 #define fits_modify_key_fixflt ffmkyf
 #define fits_modify_key_flt    ffmkye
 #define fits_modify_key_fixdbl ffmkyg
@@ -388,6 +392,7 @@
 #define fits_decompress_img fits_decomp_img
 
 #define fits_read_col        ffgcv
+#define fits_read_cols       ffgcvn
 #define fits_read_colnull    ffgcf
 #define fits_read_col_str    ffgcvs
 #define fits_read_col_log    ffgcvl
@@ -521,6 +526,7 @@
 #define fits_write_subset_dbl  ffpssd
 
 #define fits_write_col         ffpcl
+#define fits_write_cols        ffpcln
 #define fits_write_col_str     ffpcls
 #define fits_write_col_log     ffpcll
 #define fits_write_col_byt     ffpclb
@@ -577,6 +583,7 @@
 #define fits_copy_col     ffcpcl
 #define fits_copy_cols    ffccls
 #define fits_copy_rows    ffcprw
+#define fits_copy_selrows    ffcpsr
 #define fits_modify_vector_len  ffmvec
 
 #define fits_read_img_coord ffgics
